@@ -1,33 +1,15 @@
 package Web::Simple::Role;
-use strictures 1;
-use 5.008;
-use warnings::illegalproto ();
-use Moo::Role ();
-
-our $VERSION = '0.026_001'; # TRIAL RELEASE
-
-sub import {
-  my ($class, $app_package) = @_;
-  $app_package ||= caller;
-  eval "package $app_package; use Web::Dispatch::Wrapper; use Moo::Role; 1"
-    or die "Failed to setup app package: $@";
-  strictures->import;
-  warnings::illegalproto->unimport;
-}
-
-1;
-__END__
 
 =head1 NAME
 
-Web::Simple::Role - Define roles for Web::Simple applications
+Web::Simple::Role
 
 =head1 SYNOPSIS
 
   package MyApp;
   use Web::Simple;
   with MyApp::Role;
-
+  
   sub dispatch_request { ... }
 
 and in the role:
@@ -45,12 +27,28 @@ and in the role:
 
 Now C<MyApp> can also dispatch C</baz>
 
-=head1 AUTHORS
+=cut
 
-See L<Web::Simple> for authors.
+use strictures 1;
+use 5.008;
+use warnings::illegalproto ();
+use Moo::Role ();
 
-=head1 COPYRIGHT AND LICENSE
+our $VERSION = '0.020';
 
-See L<Web::Simple> for the copyright and license.
+sub import {
+  my ($class, $app_package) = @_;
+  $app_package ||= caller;
+  eval "package $app_package; use Web::Dispatch::Wrapper; use Moo::Role; 1"
+    or die "Failed to setup app package: $@";
+  strictures->import;
+  warnings::illegalproto->unimport;
+}
+
+=head1 AUTHOR
+
+osfameron@cpan.org
 
 =cut
+
+1;
